@@ -57,12 +57,10 @@ is_release = not(sunpy_version.is_prerelease or sunpy_version.is_devrelease)
 if is_release:
     warnings.simplefilter("ignore")
 warnings.filterwarnings("error", category=SunpyDeprecationWarning)
+warnings.filterwarnings("ignore", message='The sunpy.database module is no longer actively maintained', category=SunpyDeprecationWarning)
 warnings.filterwarnings("error", category=SunpyPendingDeprecationWarning)
 warnings.filterwarnings("error", category=MatplotlibDeprecationWarning)
 warnings.filterwarnings("error", category=AstropyDeprecationWarning)
-warnings.filterwarnings("ignore",
-                        message="The `sunpy.io.fits` module is deprecated",
-                        category=SunpyDeprecationWarning)
 
 # -- SunPy Sample Data and Config ----------------------------------------------
 # We set the logger to debug so that we can see any sample data download errors
@@ -70,6 +68,7 @@ warnings.filterwarnings("ignore",
 ori_level = sunpy.log.level
 sunpy.log.setLevel("DEBUG")
 import sunpy.data.sample  # NOQA
+sunpy.data.sample.download_all()
 sunpy.log.setLevel(ori_level)
 
 # For the linkcheck
@@ -199,6 +198,7 @@ intersphinx_mapping = {
     "sunkit_instruments": ("https://docs.sunpy.org/projects/sunkit-instruments/en/stable/", None),
     "zeep": ("https://docs.python-zeep.org/en/stable/", None),
     "asdf": ("https://asdf.readthedocs.io/en/stable/", None),
+    "hvpy": ("https://hvpy.readthedocs.io/en/latest/", None),
 }
 
 # -- Options for HTML output ---------------------------------------------------
