@@ -68,7 +68,8 @@ print(loop_coords[[0, -1]])
 
 aiamap = sunpy.map.Map(AIA_171_IMAGE)
 
-ax = plt.subplot(projection=aiamap)
+fig = plt.figure()
+ax = fig.add_subplot(projection=aiamap)
 aiamap.plot(axes=ax, clip_interval=(1, 99.5) * u.percent)
 ax.plot_coord(loop_coords, 'r')
 
