@@ -14,37 +14,14 @@ from astropy.coordinates import SkyCoord
 
 import sunpy.coordinates.wcs_utils
 import sunpy.map
-from sunpy.net import Fido
-from sunpy.net import attrs as a
-
-###############################################################################
-# The first step is to download some data. We download an image from STEREO-A
-# and an image from SDO, which are separated in longitude.
-
-stereo = (a.Source('STEREO_A') &
-          a.Instrument("EUVI") &
-          a.Time('2021-01-01 00:06', '2021-01-01 00:07'))
-
-aia = (a.Instrument.aia &
-       a.Sample(24 * u.hour) &
-       a.Time('2021-01-01 00:06', '2021-01-02 00:06'))
-
-wave = a.Wavelength(30 * u.nm, 31 * u.nm)
-result = Fido.search(wave, aia | stereo)
-
-###############################################################################
-# Let's inspect the result and download the files.
-
-print(result)
-downloaded_files = Fido.fetch(result)
-print(downloaded_files)
+from sunpy.data.sample import AIA_193_JUN2012, STEREO_B_195_JUN2012
 
 ##############################################################################
 # Let's create a dictionary with the two maps, which we crop to full disk.
 
 maps = {m.detector: m.submap(SkyCoord([-1100, 1100], [-1100, 1100],
                                       unit=u.arcsec, frame=m.coordinate_frame))
-        for m in sunpy.map.Map(downloaded_files)}
+        for m in sunpy.map.Map([AIA_193_JUN2012, STEREO_B_195_JUN2012])}
 maps['AIA'].plot_settings['vmin'] = 0  # set the minimum plotted pixel value
 
 ##############################################################################
