@@ -1,30 +1,12 @@
 """
-SunPy
-=====
+``sunpy``
+=========
 
 An open-source Python library for Solar Physics data analysis.
 
 * Homepage: https://sunpy.org
 * Documentation: https://docs.sunpy.org/en/stable/
 """
-import os
-import sys
-
-# Enforce Python version check during package import.
-# Must be done before any sunpy imports
-__minimum_python_version__ = "3.7"
-
-
-class UnsupportedPythonError(Exception):
-    """Running on an unsupported version of Python."""
-
-
-if sys.version_info < tuple(int(val) for val in __minimum_python_version__.split('.')):
-    # This has to be .format to keep backwards compatibly.
-    raise UnsupportedPythonError(
-        "sunpy does not support Python < {}".format(__minimum_python_version__))
-
-
 from sunpy.tests.self_test import self_test
 from sunpy.util import system_info
 from sunpy.util.config import load_config, print_config
@@ -33,6 +15,7 @@ from .version import version as __version__
 
 
 def _get_bibtex():
+    import os
     import textwrap
 
     # Set the bibtex entry to the article referenced in CITATION.rst
@@ -50,10 +33,7 @@ def _get_bibtex():
 
 
 __citation__ = __bibtex__ = _get_bibtex()
-
-# Load user configuration
 config = load_config()
-
 log = _init_log(config=config)
 
-__all__ = ['config', 'self_test', 'system_info', 'print_config']
+__all__ = ['config', 'self_test', 'system_info', 'print_config', 'log', '__version__', '__citation__', '__bibtex__']
