@@ -2,17 +2,15 @@
 Coordinate frames that are defined relative to other frames
 """
 
-from astropy import units as u
-from astropy.coordinates import SphericalRepresentation
+import astropy.units as u
 from astropy.coordinates.attributes import Attribute, QuantityAttribute
 from astropy.coordinates.baseframe import frame_transform_graph
 from astropy.coordinates.transformations import FunctionTransform
 
-from sunpy import log
 from sunpy.time import parse_time
 from sunpy.time.time import _variables_for_parse_time_docstring
 from sunpy.util.decorators import add_common_docstring
-from .frames import BaseHeliographic, HeliocentricInertial, SunPyBaseCoordinateFrame
+from .frames import HeliographicStonyhurst, SunPyBaseCoordinateFrame
 from .offset_frame import NorthOffsetFrame
 from .transformations import _transformation_debug
 
@@ -54,14 +52,6 @@ def _make_rotatedsun_cls(framecls):
     for attr in attrs_to_copy:
         members[attr] = getattr(framecls, attr)
 
-    # Frames based on BaseHeliographic need to include the auto-upgrading from 2D to 3D
-    if issubclass(framecls, BaseHeliographic):
-        def baseheliographic_init(self, *args, **kwargs):
-            RotatedSunFrame.__init__(self, *args, **kwargs)
-            BaseHeliographic._make_3d(self)
-
-        members['__init__'] = baseheliographic_init
-
     _RotatedSunFramecls = type(f'RotatedSun{framecls.__name__}', (RotatedSunFrame,), members)
 
     @frame_transform_graph.transform(FunctionTransform, _RotatedSunFramecls, _RotatedSunFramecls)
@@ -69,53 +59,41 @@ def _make_rotatedsun_cls(framecls):
     def rotatedsun_to_rotatedsun(from_rotatedsun_coord, to_rotatedsun_frame):
         """Transform between two rotated-Sun frames."""
         # This transform goes through the parent frames on each side.
-        # from_frame -> from_frame.base -> to_frame.base -> to_frame
-        intermediate_from = from_rotatedsun_coord.transform_to(from_rotatedsun_coord.base)
-        intermediate_to = intermediate_from.transform_to(to_rotatedsun_frame.base)
-        return intermediate_to.transform_to(to_rotatedsun_frame)
+        # from_frame -> HGS -> to_frame
+        int_frame = HeliographicStonyhurst(obstime=from_rotatedsun_coord.base.obstime)
+        int_coord = from_rotatedsun_coord.transform_to(int_frame)
+        return int_coord.transform_to(to_rotatedsun_frame)
 
-    @frame_transform_graph.transform(FunctionTransform, framecls, _RotatedSunFramecls)
-    @_transformation_debug(f"{framecls.__name__}->{_RotatedSunFramecls.__name__}")
-    def reference_to_rotatedsun(reference_coord, rotatedsun_frame):
-        # Transform to HCI
-        hci_frame = HeliocentricInertial(obstime=rotatedsun_frame.base.obstime)
-        hci_coord = reference_coord.transform_to(hci_frame)  # obstime change handled here
-        oldrepr = hci_coord.spherical
+    @frame_transform_graph.transform(FunctionTransform, HeliographicStonyhurst, _RotatedSunFramecls)
+    @_transformation_debug(f"HGS->{_RotatedSunFramecls.__name__}")
+    def reference_to_rotatedsun(hgs_coord, rotatedsun_frame):
+        int_frame = HeliographicStonyhurst(obstime=rotatedsun_frame.base.obstime)
+        int_coord = hgs_coord.make_3d().transform_to(int_frame)  # obstime change handled here
 
-        # Rotate the coordinate in HCI
-        from sunpy.physics.differential_rotation import diff_rot
-        log.debug(f"Applying {rotatedsun_frame.duration} of solar rotation")
-        newlon = oldrepr.lon - diff_rot(rotatedsun_frame.duration,
-                                        oldrepr.lat,
-                                        rot_type=rotatedsun_frame.rotation_model,
-                                        frame_time='sidereal')
-        newrepr = SphericalRepresentation(newlon, oldrepr.lat, oldrepr.distance)
+        # Rotate the coordinate in HGS
+        int_coord = int_coord._apply_diffrot(-rotatedsun_frame.duration,
+                                             rotatedsun_frame.rotation_model)
 
-        # Transform back from HCI
-        new_coord = hci_coord.realize_frame(newrepr).transform_to(rotatedsun_frame.base)
+        # Transform from HGS
+        new_coord = int_coord.transform_to(rotatedsun_frame.base)
         return rotatedsun_frame.realize_frame(new_coord.data)
 
-    @frame_transform_graph.transform(FunctionTransform, _RotatedSunFramecls, framecls)
-    @_transformation_debug(f"{_RotatedSunFramecls.__name__}->{framecls.__name__}")
-    def rotatedsun_to_reference(rotatedsun_coord, reference_frame):
-        # Transform to HCI
+    @frame_transform_graph.transform(FunctionTransform, _RotatedSunFramecls, HeliographicStonyhurst)
+    @_transformation_debug(f"{_RotatedSunFramecls.__name__}->HGS")
+    def rotatedsun_to_reference(rotatedsun_coord, hgs_frame):
+        # Transform to HGS
         from_coord = rotatedsun_coord.base.realize_frame(rotatedsun_coord.data)
-        hci_frame = HeliocentricInertial(obstime=rotatedsun_coord.base.obstime)
-        hci_coord = from_coord.transform_to(hci_frame)
-        oldrepr = hci_coord.spherical
+        if hasattr(from_coord, 'make_3d'):
+            from_coord = from_coord.make_3d()
+        int_frame = HeliographicStonyhurst(obstime=rotatedsun_coord.base.obstime)
+        int_coord = from_coord.transform_to(int_frame)
 
-        # Rotate the coordinate in HCI
-        from sunpy.physics.differential_rotation import diff_rot
-        log.debug(f"Applying {rotatedsun_coord.duration} of solar rotation")
-        newlon = oldrepr.lon + diff_rot(rotatedsun_coord.duration,
-                                        oldrepr.lat,
-                                        rot_type=rotatedsun_coord.rotation_model,
-                                        frame_time='sidereal')
-        newrepr = SphericalRepresentation(newlon, oldrepr.lat, oldrepr.distance)
+        # Rotate the coordinate in HGS
+        int_coord = int_coord._apply_diffrot(rotatedsun_coord.duration,
+                                             rotatedsun_coord.rotation_model)
 
-        # Transform back from HCI
-        hci_coord = hci_frame.realize_frame(newrepr)
-        return hci_coord.transform_to(reference_frame)  # obstime change handled here
+        # Transform from HGS
+        return int_coord.transform_to(hgs_frame)  # obstime change handled here
 
     _rotatedsun_cache[framecls] = _RotatedSunFramecls
     return _RotatedSunFramecls
@@ -148,7 +126,7 @@ class RotatedSunFrame(SunPyBaseCoordinateFrame):
         The time to rotate the Sun to.  If provided, ``duration`` will be set to the difference
         between this time and the observation time in ``base``.
     rotation_model : `str`
-        Accepted model names are ``'howard'`` (default), ``'snodgrass'``, and ``'allen'``.
+        Accepted model names are ``'howard'`` (default), ``'snodgrass'``, ``'allen'``, and ``'rigid'``.
         See the documentation for :func:`~sunpy.physics.differential_rotation.diff_rot` for differences
         between these models.
 
@@ -238,6 +216,13 @@ class RotatedSunFrame(SunPyBaseCoordinateFrame):
         """
         return self.base.obstime + self.duration
 
+    def __reduce__(self):
+        return (_rotatedsunframe_reducer, (self.base,), self.__dict__)
+
+
+def _rotatedsunframe_reducer(base):
+    return RotatedSunFrame.__new__(RotatedSunFrame, base=base)
+
 
 # For Astropy 4.3+, we need to manually remove the `obstime` frame attribute from RotatedSunFrame
 if 'obstime' in RotatedSunFrame.frame_attributes:
