@@ -168,11 +168,11 @@ def split_database(source_database, destination_database, *query_string):
     >>> from sunpy.net import vso, attrs as a
     >>> database1 = Database('sqlite:///:memory:')
     >>> database2 = Database('sqlite:///:memory:')
-    >>> client = vso.VSOClient()  # doctest: +REMOTE_DATA
-    >>> qr = client.search(a.Time('2011-05-08', '2011-05-08 00:00:05'), response_format="legacy")  # doctest: +REMOTE_DATA
-    >>> database1.add_from_vso_query_result(qr)  # doctest: +REMOTE_DATA
+    >>> client = vso.VSOClient()  # doctest: +SKIP
+    >>> qr = client.search(a.Time('2011-05-08', '2011-05-08 00:00:05'), response_format="legacy")  # doctest: +SKIP
+    >>> database1.add_from_vso_query_result(qr)  # doctest: +SKIP
     >>> database1, database2 = split_database(database1, database2,
-    ...            a.Instrument.aia | a.Instrument.erne)  # doctest: +REMOTE_DATA
+    ...            a.Instrument.aia | a.Instrument.erne)  # doctest: +SKIP
     """
 
     query_string = and_(*query_string)
@@ -520,10 +520,10 @@ class Database:
         >>> from sunpy.net import vso, attrs as a
         >>> database = Database('sqlite:///:memory:')
         >>> database.fetch(a.Time('2012-08-05', '2012-08-05 00:00:05'),
-        ...                a.Instrument.aia)  # doctest: +REMOTE_DATA
+        ...                a.Instrument.aia)  # doctest: +SKIP
         >>> print(display_entries(database,
         ...                       ['id', 'observation_time_start', 'observation_time_end',
-        ...                        'instrument', 'wavemin', 'wavemax']))  # doctest: +REMOTE_DATA
+        ...                        'instrument', 'wavemin', 'wavemax']))  # doctest: +SKIP
             id observation_time_start observation_time_end instrument wavemin wavemax
             --- ---------------------- -------------------- ---------- ------- -------
               1    2012-08-05 00:00:01  2012-08-05 00:00:02        AIA     9.4     9.4
@@ -531,10 +531,10 @@ class Database:
               3    2012-08-05 00:00:02  2012-08-05 00:00:03        AIA    33.5    33.5
               4    2012-08-05 00:00:02  2012-08-05 00:00:03        AIA    33.5    33.5
         >>> database.fetch(a.Time('2012-08-05', '2012-08-05 00:00:01'),
-        ...                a.Instrument.aia, overwrite=True)  # doctest: +REMOTE_DATA
+        ...                a.Instrument.aia, overwrite=True)  # doctest: +SKIP
         >>> print(display_entries(database,
         ...                       ['id', 'observation_time_start', 'observation_time_end',
-        ...                        'instrument', 'wavemin', 'wavemax']))  # doctest: +REMOTE_DATA
+        ...                        'instrument', 'wavemin', 'wavemax']))  # doctest: +SKIP
              id observation_time_start observation_time_end instrument wavemin wavemax
             --- ---------------------- -------------------- ---------- ------- -------
               3    2012-08-05 00:00:02  2012-08-05 00:00:03        AIA    33.5    33.5
