@@ -6,6 +6,13 @@ Based on Michiel van Noort's IDL DLM library 'f0' which contains
 a cleaned up version of the original anarw routines.
 */
 
+#define Py_LIMITED_API 0x030800f0
+
+// Needed due to https://github.com/numpy/numpy/issues/16970
+struct _typeobject {
+  int foo;
+};
+
 #include <Python.h>				// For python extension
 #define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
 #include <numpy/arrayobject.h> 	// For numpy
