@@ -42,6 +42,11 @@ class EITMap(GenericMap):
         self.plot_settings['norm'] = ImageNormalize(
             stretch=source_stretch(self.meta, PowerStretch(0.5)), clip=False)
 
+    @property
+    def date(self):
+        # Old EIT data has date-obs in format of dd-JAN-yy so we use date_obs where available
+        return self._get_date('date_obs') or super().date
+
     @property
     def spatial_units(self):
         """
