@@ -51,6 +51,28 @@ def test_plot_composite_map_linewidths(composite_test_map):
     composite_test_map.plot(linewidths=0.5)
 
 
+@figure_test
+def test_plot_composite_map_linestyles(composite_test_map):
+    composite_test_map.set_levels(1, np.arange(-75, 76, 25) << u.percent)
+    composite_test_map.plot(linestyles='--')
+
+
+@figure_test
+def test_plot_composite_map_colors(composite_test_map):
+    composite_test_map.set_levels(1, np.arange(-75, 76, 25) << u.percent)
+    composite_test_map.plot(colors='red')
+
+
+def test_plot_composite_map_mplkwargs(composite_test_map):
+    composite_test_map.set_levels(1, np.arange(-75, 76, 25) << u.percent)
+    with pytest.raises(TypeError) as e:
+        composite_test_map.plot(linestyles='--', unused_a=1, unused_b=2)
+    assert 'plot() got unexpected keyword arguments' in str(e.value)
+    assert 'unused_a' in str(e.value)
+    assert 'unused_b' in str(e.value)
+    assert 'linestyles' not in str(e.value)
+
+
 def test_remove_composite_map(composite_test_map):
     composite_test_map.remove_map(0)
     with pytest.raises(IndexError):
@@ -86,10 +108,10 @@ def test_set_alpha_composite_map(composite_test_map):
     composite_test_map.plot()
 
 
-def test_set_alpha_out_of_range_composite_map(composite_test_map):
+@pytest.mark.parametrize("index,alpha", [(0, 5.0), (1, -3.0)])
+def test_set_alpha_out_of_range_composite_map(composite_test_map, index, alpha):
     with pytest.raises(Exception) as excinfo:
-        composite_test_map.set_alpha(0, 5.0)
-        composite_test_map.set_alpha(1, -3.0)
+        composite_test_map.set_alpha(index, alpha)
     assert str(excinfo.value) == 'Alpha value must be between 0 and 1.'
 
 
