@@ -4,7 +4,6 @@ Test Generic Map
 import re
 import tempfile
 import contextlib
-from unittest import mock
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -33,7 +32,7 @@ from sunpy.map.sources import AIAMap
 from sunpy.tests.helpers import figure_test
 from sunpy.time import parse_time
 from sunpy.util import SunpyUserWarning
-from sunpy.util.exceptions import SunpyDeprecationWarning, SunpyMetadataWarning
+from sunpy.util.exceptions import SunpyMetadataWarning
 from sunpy.util.metadata import ModifiedItem
 from sunpy.visualization.colormaps.cm import _get_mpl_cmap
 from .conftest import make_simple_map
@@ -464,54 +463,13 @@ def test_save_compressed(aia171_test_map):
     assert isinstance(loaded_save, sunpy.map.sources.AIAMap)
 
 
-DEP_WARNING_SHIFTED_VAL = (
-    'ignore:`sunpy.map.GenericMap.shifted_value` is deprecated and will be removed in sunpy 4.1. '
-    'Use ``sunpy.map.GenericMap.meta.modified_items`` to see how the reference coordinate has been '
-    'modified.:sunpy.util.exceptions.SunpyDeprecationWarning'
-)
-DEP_WARNING_SHIFT = (
-    'ignore:The shift function is deprecated and may be removed in version 4.1.'
-    r'\s+Use `sunpy.map.GenericMap.shift_reference_coord` instead.'
-    ':sunpy.util.exceptions.SunpyDeprecationWarning'
-)
-
-
-@pytest.mark.filterwarnings(DEP_WARNING_SHIFTED_VAL)
-def test_default_shift():
-    """Test that the default shift is zero"""
-    data = np.ones([6, 6], dtype=np.float64)
-    header = {
-        'CRVAL1': 0,
-        'CRVAL2': 0,
-        'CRPIX1': 5,
-        'CRPIX2': 5,
-        'CDELT1': 10,
-        'CDELT2': 9,
-        'CD1_1': 0,
-        'CD1_2': -9,
-        'CD2_1': 10,
-        'CD2_2': 0,
-        'NAXIS1': 6,
-        'NAXIS2': 6,
-        'CUNIT1': 'arcsec',
-        'CUNIT2': 'arcsec',
-        'CTYPE1': 'HPLN-TAN',
-        'CTYPE2': 'HPLT-TAN',
-    }
-    cd_map = sunpy.map.Map((data, header))
-    assert cd_map.shifted_value[0].value == 0
-    assert cd_map.shifted_value[1].value == 0
-
-
-@pytest.mark.filterwarnings(DEP_WARNING_SHIFT)
-@pytest.mark.filterwarnings(DEP_WARNING_SHIFTED_VAL)
 def test_shift_applied(generic_map):
     """Test that adding a shift actually updates the reference coordinate"""
     original_reference_coord = (generic_map.reference_coordinate.Tx,
                                 generic_map.reference_coordinate.Ty)
     x_shift = 5 * u.arcsec
     y_shift = 13 * u.arcsec
-    shifted_map = generic_map.shift(x_shift, y_shift)
+    shifted_map = generic_map.shift_reference_coord(x_shift, y_shift)
     assert shifted_map.reference_coordinate.Tx - x_shift == original_reference_coord[0]
     assert shifted_map.reference_coordinate.Ty - y_shift == original_reference_coord[1]
     crval1 = ((generic_map.meta.get('crval1') * generic_map.spatial_units[0] +
@@ -522,30 +480,26 @@ def test_shift_applied(generic_map):
     assert shifted_map.meta.get('crval2') == crval2
 
 
-@pytest.mark.filterwarnings(DEP_WARNING_SHIFT)
-@pytest.mark.filterwarnings(DEP_WARNING_SHIFTED_VAL)
 def test_set_shift(generic_map):
     """Test that previously applied shift is stored in the shifted_value property"""
     x_shift = 5 * u.arcsec
     y_shift = 13 * u.arcsec
-    shifted_map = generic_map.shift(x_shift, y_shift)
+    shifted_map = generic_map.shift_reference_coord(x_shift, y_shift)
     mod_crval1 = shifted_map.meta.modified_items['crval1']
     mod_crval2 = shifted_map.meta.modified_items['crval2']
     assert x_shift == (mod_crval1.current - mod_crval1.original) * shifted_map.spatial_units[0]
     assert y_shift == (mod_crval2.current - mod_crval2.original) * shifted_map.spatial_units[1]
 
 
-@pytest.mark.filterwarnings(DEP_WARNING_SHIFT)
-@pytest.mark.filterwarnings(DEP_WARNING_SHIFTED_VAL)
 def test_shift_history(generic_map):
     """Test the shifted_value is added to a non-zero previous shift"""
     x_shift1 = 5 * u.arcsec
     y_shift1 = 13 * u.arcsec
-    shifted_map1 = generic_map.shift(x_shift1, y_shift1)
+    shifted_map1 = generic_map.shift_reference_coord(x_shift1, y_shift1)
 
     x_shift2 = -28.5 * u.arcsec
     y_shift2 = 120 * u.arcsec
-    final_shifted_map = shifted_map1.shift(x_shift2, y_shift2)
+    final_shifted_map = shifted_map1.shift_reference_coord(x_shift2, y_shift2)
 
     mod_crval1 = final_shifted_map.meta.modified_items['crval1']
     mod_crval2 = final_shifted_map.meta.modified_items['crval2']
@@ -713,28 +667,25 @@ def test_resample(simple_map, shape):
     assert u.allclose(resampled_upper_left.Ty, original_upper_left.Ty)
 
 
-resample_test_data = [('linear', (100, 200) * u.pixel, contextlib.nullcontext()),
-                      ('neighbor', (128, 256) * u.pixel, pytest.warns(SunpyDeprecationWarning)),
-                      ('nearest', (512, 128) * u.pixel, contextlib.nullcontext()),
-                      ('spline', (200, 200) * u.pixel, contextlib.nullcontext())]
+resample_test_data = [('linear', (100, 200) * u.pixel),
+                      ('nearest', (512, 128) * u.pixel),
+                      ('spline', (200, 200) * u.pixel)]
 
 
-@pytest.mark.parametrize('sample_method, new_dimensions, cm', resample_test_data)
-def test_resample_dimensions(generic_map, sample_method, new_dimensions, cm):
+@pytest.mark.parametrize('sample_method, new_dimensions', resample_test_data)
+def test_resample_dimensions(generic_map, sample_method, new_dimensions):
     """Check that resampled map has expected dimensions."""
-    with cm:
-        resampled_map = generic_map.resample(new_dimensions, method=sample_method)
-        assert resampled_map.dimensions[0] == new_dimensions[0]
-        assert resampled_map.dimensions[1] == new_dimensions[1]
+    resampled_map = generic_map.resample(new_dimensions, method=sample_method)
+    assert resampled_map.dimensions[0] == new_dimensions[0]
+    assert resampled_map.dimensions[1] == new_dimensions[1]
 
 
-@pytest.mark.parametrize('sample_method, new_dimensions, cm', resample_test_data)
-def test_resample_metadata(generic_map, sample_method, new_dimensions, cm):
+@pytest.mark.parametrize('sample_method, new_dimensions', resample_test_data)
+def test_resample_metadata(generic_map, sample_method, new_dimensions):
     """
     Check that the resampled map has correctly adjusted metadata.
     """
-    with cm:
-        resampled_map = generic_map.resample(new_dimensions, method=sample_method)
+    resampled_map = generic_map.resample(new_dimensions, method=sample_method)
 
     scale_x = generic_map.data.shape[1] / resampled_map.data.shape[1]
     scale_y = generic_map.data.shape[0] / resampled_map.data.shape[0]
@@ -761,19 +712,18 @@ def test_resample_metadata(generic_map, sample_method, new_dimensions, cm):
             assert resampled_map.meta[key] == generic_map.meta[key]
 
 
-@pytest.mark.parametrize('sample_method, new_dimensions, cm', resample_test_data)
-def test_resample_simple_map(simple_map, sample_method, new_dimensions, cm):
+@pytest.mark.parametrize('sample_method, new_dimensions', resample_test_data)
+def test_resample_simple_map(simple_map, sample_method, new_dimensions):
     # Put the reference pixel at the top-right of the bottom-left pixel
     simple_map.meta['crpix1'] = 1.5
     simple_map.meta['crpix2'] = 1.5
     assert list(simple_map.reference_pixel) == [0.5 * u.pix, 0.5 * u.pix]
     # Make the superpixel map
     new_dims = (9, 6) * u.pix
-    with cm:
-        resamp_map = simple_map.resample(new_dims, method=sample_method)
-        # Reference pixel should change, but reference coordinate should not
-        assert list(resamp_map.reference_pixel) == [2.5 * u.pix, 1.5 * u.pix]
-        assert resamp_map.reference_coordinate == simple_map.reference_coordinate
+    resamp_map = simple_map.resample(new_dims, method=sample_method)
+    # Reference pixel should change, but reference coordinate should not
+    assert list(resamp_map.reference_pixel) == [2.5 * u.pix, 1.5 * u.pix]
+    assert resamp_map.reference_coordinate == simple_map.reference_coordinate
 
 
 def test_superpixel_simple_map(simple_map):
@@ -1225,20 +1175,17 @@ def test_repr_html(aia171_test_map):
     assert "Bad pixels are shown in red: 1 infinite" in html_string
 
 
-def test_quicklook(aia171_test_map):
-    with mock.patch('webbrowser.open_new_tab') as mockwbopen:
-        aia171_test_map.quicklook()
-
+def test_quicklook(mocker, aia171_test_map):
+    mockwbopen = mocker.patch('webbrowser.open_new_tab')
+    aia171_test_map.quicklook()
     # Check that the mock web browser was opened with a file URL
     mockwbopen.assert_called_once()
     file_url = mockwbopen.call_args[0][0]
     assert file_url.startswith('file://')
-
     # Open the file specified in the URL and confirm that it contains the HTML
     with open(file_url[7:], 'r') as f:
         html_string = f.read()
-
-        assert aia171_test_map._repr_html_() in html_string
+    assert aia171_test_map._repr_html_() in html_string
 
 
 def test_dask_array(generic_map):
