@@ -1,12 +1,9 @@
 """
 A Module for accessing the HELIO web service
-
-.. warning::
-    This module is still in beta and may be unstable
-
 """
 
+from .chaincode import *
 from .hec import *
 from .parser import *
 
-__all__ = ['HECClient', 'HECResponse']
+__all__ = ['HECClient', 'HECResponse', 'Chaincode']
