@@ -53,7 +53,7 @@ if Version(python_version()) >= Version("3.10.0"):
     )
 else:
     asdf_entry_points = pytest.mark.skipif(
-        not all(
+        not any(
             [
                 enter_point.name == "sunpy"
                 for enter_point in entry_points()["asdf.resource_mappings"]
@@ -77,7 +77,7 @@ def get_hash_library_name():
     version = mpl_animators.__version__
     animators_version = "dev" if "+" in version else version.replace('.', '')
     ft2_version = f"{mpl.ft2font.__freetype_version__.replace('.', '')}"
-    mpl_version = "dev" if "+" in mpl.__version__ else mpl.__version__.replace('.', '')
+    mpl_version = "dev" if ("+" in mpl.__version__) or ("rc" in mpl.__version__) else mpl.__version__.replace('.', '')
     astropy_version = "dev" if "dev" in astropy.__version__ else astropy.__version__.replace('.', '')
     return f"figure_hashes_mpl_{mpl_version}_ft_{ft2_version}_astropy_{astropy_version}_animators_{animators_version}.json"
 
