@@ -13,6 +13,7 @@ from astropy.time import TimeDelta
 import sunpy.io
 from sunpy.time import parse_time
 from sunpy.timeseries.timeseriesbase import GenericTimeSeries
+from sunpy.util.decorators import deprecate_positional_args_since
 from sunpy.util.metadata import MetaDict
 from sunpy.visualization import peek_show
 
@@ -61,10 +62,12 @@ class GBMSummaryTimeSeries(GenericTimeSeries):
     * `Fermi Data Product <https://fermi.gsfc.nasa.gov/ssc/data/access/>`_
     * `GBM Instrument Papers <https://gammaray.nsstc.nasa.gov/gbm/publications/instrument_journal_gbm.html>`_
     """
-    # Class attribute used to specify the source class of the TimeSeries.
+    # Class attributes used to specify the source class of the TimeSeries
+    # and a URL to the mission website.
     _source = 'gbmsummary'
+    _url = "https://gammaray.nsstc.nasa.gov/gbm/#"
 
-    def plot(self, axes=None, **kwargs):
+    def plot(self, axes=None, columns=None, **kwargs):
         """
         Plots the GBM timeseries.
 
@@ -72,6 +75,8 @@ class GBMSummaryTimeSeries(GenericTimeSeries):
         ----------
         axes : `matplotlib.axes.Axes`, optional
             The axes on which to plot the TimeSeries. Defaults to current axes.
+        columns : list[str], optional
+            If provided, only plot the specified columns.
         **kwargs : `dict`
             Additional plot keyword arguments that are handed to `~matplotlib.axes.Axes.plot`
             functions.
@@ -81,20 +86,18 @@ class GBMSummaryTimeSeries(GenericTimeSeries):
         `~matplotlib.axes.Axes`
             The plot axes.
         """
-        self._validate_data_for_plotting()
-        if axes is None:
-            axes = plt.gca()
-        data_lab = self.to_dataframe().columns.values
-        for d in data_lab:
-            axes.plot(self.to_dataframe().index, self.to_dataframe()[d], label=d, **kwargs)
+        axes, columns = self._setup_axes_columns(axes, columns)
+        for d in columns:
+            axes.plot(self._data.index, self._data[d], label=d, **kwargs)
         axes.set_yscale("log")
-        axes.set_xlabel('Start time: ' + self.to_dataframe().index[0].strftime('%Y-%m-%d %H:%M:%S UT'))
         axes.set_ylabel('Counts/s/keV')
         axes.legend()
+        self._setup_x_axis(axes)
         return axes
 
     @peek_show
-    def peek(self, title=None, **kwargs):
+    @deprecate_positional_args_since("4.1")
+    def peek(self, *, title=None, columns=None, **kwargs):
         """
         Displays the GBM timeseries by calling
         `~sunpy.timeseries.sources.fermi_gbm.GBMSummaryTimeSeries.plot`.
@@ -110,6 +113,8 @@ class GBMSummaryTimeSeries(GenericTimeSeries):
         ----------
         title : `str`, optional
             The title of the plot.
+        columns : list[str], optional
+            If provided, only plot the specified columns.
         **kwargs : `dict`
             Additional plot keyword arguments that are handed to `~matplotlib.axes.Axes.plot`
             functions.
@@ -117,9 +122,8 @@ class GBMSummaryTimeSeries(GenericTimeSeries):
         if title is None:
             title = 'Fermi GBM Summary data ' + str(self.meta.get('DETNAM').values())
         fig, ax = plt.subplots()
-        axes = self.plot(axes=ax, **kwargs)
+        axes = self.plot(axes=ax, columns=columns, **kwargs)
         axes.set_title(title)
-        fig.autofmt_xdate()
         return fig
 
     @classmethod
