@@ -11,14 +11,14 @@ from pandas.testing import assert_frame_equal
 import astropy.units as u
 from astropy.table import Table
 from astropy.tests.helper import assert_quantity_allclose
-from astropy.time import TimeDelta
+from astropy.time import Time, TimeDelta
 
 import sunpy
 import sunpy.timeseries
 from sunpy.tests.helpers import figure_test
 from sunpy.time import TimeRange, parse_time
 from sunpy.timeseries import TimeSeriesMetaData
-from sunpy.util import SunpyUserWarning
+from sunpy.util import SunpyDeprecationWarning, SunpyUserWarning
 from sunpy.util.metadata import MetaDict
 
 # Test fixtures are in ../conftest.py
@@ -494,7 +494,12 @@ def test_equality_different_ts_types(generic_ts, eve_test_ts):
 
 
 def test_ts_index(generic_ts):
-    assert (generic_ts.index == generic_ts.to_dataframe().index).all()
+    with pytest.warns(SunpyDeprecationWarning, match='.index is deprecatd'):
+        assert (generic_ts.index == generic_ts.to_dataframe().index).all()
+
+
+def test_ts_time(generic_ts):
+    assert isinstance(generic_ts.time, Time)
 
 
 def test_ts_shape(generic_ts):
@@ -505,6 +510,38 @@ def test_ts_sort_index(generic_ts):
     assert generic_ts.sort_index().to_dataframe().equals(generic_ts.to_dataframe().sort_index())
 
 
+def test_repr_html_(generic_ts):
+    html_string = generic_ts._repr_html_()
+    assert isinstance(html_string, str)
+
+
+def test_quicklook(mocker, generic_ts):
+    mockwbopen = mocker.patch('webbrowser.open_new_tab')
+    generic_ts.quicklook()
+    mockwbopen.assert_called_once()
+    file_url = mockwbopen.call_args[0][0]
+    assert file_url.startswith("file://")
+    # Open the file specified in the URL and confirm that it contains the HTML
+    with open(file_url[7:], 'r') as f:
+        html_string = f.read()
+    if generic_ts.source is None:
+        name = "None"
+    else:
+        name = generic_ts.source
+    # The two sections below remove a random name from the two strings
+    # before the assertion
+    h1 = html_string.find(name)
+    h2 = html_string.find(" = new ImageChange")
+    ident = html_string[h1:h2]
+    html_string = html_string.replace(ident, "same")
+    repr_html = generic_ts._repr_html_()
+    h1 = repr_html.find(name)
+    h2 = repr_html.find(" = new ImageChange")
+    ident = repr_html[h1:h2]
+    repr_html = repr_html.replace(ident, "same")
+    assert repr_html in html_string
+
+
 def test_timeseries_array():
     times = parse_time("now") - TimeDelta(np.arange(5) * u.minute)
     intensity = np.sin(np.arange(0, 12 * np.pi, step=(12 * np.pi) / (5)))
@@ -514,6 +551,11 @@ def test_timeseries_array():
         assert isinstance(ts, sunpy.timeseries.GenericTimeSeries)
 
 
+def test_deprecated_positional_peek_args(many_ts):
+    # Check that all positional arguments to peek() are deprecated
+    with pytest.warns(SunpyDeprecationWarning, match='passing these as positional arguments will result in an error'):
+        many_ts.peek(many_ts.columns[0:1])
+
 # TODO:
 # _validate_units
 # _validate_meta
