@@ -10,6 +10,7 @@ from inspect import Parameter, signature
 from functools import wraps
 
 import astropy.units as u
+from astropy.nddata import NDData
 
 from sunpy.util.exceptions import SunpyDeprecationWarning, SunpyPendingDeprecationWarning, warn_deprecated
 
@@ -262,6 +263,13 @@ class add_common_docstring:
 
 def deprecate_positional_args_since(since, keyword_only=False):
     """
+    Decorator for methods that issues warnings for positional arguments
+    Using the keyword-only argument syntax in pep 3102, arguments after the
+    * will issue a warning when passed as a positional argument.
+
+    Note that when you apply this, you also have to put at * in the signature
+    to create new keyword only parameters!
+
     Parameters
     ----------
     since : str
@@ -269,9 +277,7 @@ def deprecate_positional_args_since(since, keyword_only=False):
     """
     def deprecate_positional_args(f):
         """
-        Decorator for methods that issues warnings for positional arguments
-        Using the keyword-only argument syntax in pep 3102, arguments after the
-        * will issue a warning when passed as a positional argument.
+
 
         Parameters
         ----------
@@ -383,13 +389,10 @@ def check_arithmetic_compatibility(func):
     """
     @wraps(func)
     def inner(instance, value):
-        # Import here to avoid circular imports
-        from sunpy.map import GenericMap
-
         # This is explicit because it is expected that users will try to do this. This raises
         # a different error because it is expected that this type of operation will be supported
         # in future releases.
-        if isinstance(value, GenericMap):
+        if isinstance(value, NDData):
             return NotImplemented
         try:
             # We want to support operations between numbers and array-like objects. This includes
