@@ -12,7 +12,7 @@ from urllib.request import urlopen
 
 from sunpy.util import replacement_filename
 
-__all__ = ['slugify', 'get_content_disposition', 'get_filename', 'get_system_filename',
+__all__ = ['parse_header', 'slugify', 'get_content_disposition', 'get_filename', 'get_system_filename',
            'download_file', 'download_fileobj']
 
 # Characters not allowed in slugified version.
@@ -152,7 +152,7 @@ def download_fileobj(opn, directory, url='', default="file", overwrite=False):
         The URL to parse for the filename.
     default : `str`, optional
         The name to use if the first two methods fail. Defaults to "file".
-    overwrite: `bool`, optional
+    overwrite : `bool`, optional
         If `True` will overwrite a file of the same name. Defaults to `False`.
 
     Returns
@@ -184,7 +184,7 @@ def download_file(url, directory, default="file", overwrite=False):
         The directory path to download the file in to.
     default : `str`, optional
         The name to use if the first two methods fail. Defaults to "file".
-    overwrite: `bool`, optional
+    overwrite : `bool`, optional
         If `True` will overwrite a file of the same name. Defaults to `False`.
 
     Returns
@@ -198,3 +198,40 @@ def download_file(url, directory, default="file", overwrite=False):
     finally:
         opn.close()
     return path
+
+# These two functions were in the stdlib cgi module which was deprecated in Python 3.11
+# They are copied here under the terms of the PSF Licence 2.0
+
+
+def _parseparam(s):
+    while s[:1] == ';':
+        s = s[1:]
+        end = s.find(';')
+        while end > 0 and (s.count('"', 0, end) - s.count('\\"', 0, end)) % 2:
+            end = s.find(';', end + 1)
+        if end < 0:
+            end = len(s)
+        f = s[:end]
+        yield f.strip()
+        s = s[end:]
+
+
+def parse_header(line):
+    """Parse a Content-type like header.
+
+    Return the main content-type and a dictionary of options.
+
+    """
+    parts = _parseparam(';' + line)
+    key = parts.__next__()
+    pdict = {}
+    for p in parts:
+        i = p.find('=')
+        if i >= 0:
+            name = p[:i].strip().lower()
+            value = p[i+1:].strip()
+            if len(value) >= 2 and value[0] == value[-1] == '"':
+                value = value[1:-1]
+                value = value.replace('\\\\', '\\').replace('\\"', '"')
+            pdict[name] = value
+    return key, pdict
